UsbProxy

Struct UsbProxy 

pub struct UsbProxy<'a>(/* private fields */);
This interface provides access to USB devices.

Implementations

Source

impl<'a> UsbProxy<'a>

pub async fn new() -> Result<UsbProxy<'a>, Error>

Create a new instance of UsbProxy.

pub async fn create_session(&self) -> Result<Session<'a, Self>, Error>

Create a USB session.

While this session is active, the caller will receive DeviceEvents signals with device addition and removal.

Specifications

See also CreateSession.

pub async fn enumerate_devices(&self) -> Result<Vec<(String, UsbDevice)>, Error>

Enumerate USB devices.

Return a vector of tuples with the device ID and the UsbDevice

Specifications

See also EnumerateDevices.

pub async fn acquire_devices( &self, parent_window: Option<&WindowIdentifier>, devices: &[Device], ) -> Result<Vec<(String, Result<OwnedFd, UsbError>)>, Error>

Acquire devices

The portal will perform the permission request. In case of success, ie permission is granted, it returns a vector of tuples containing the device ID and the file descriptor or error.

Specifications

See also AcquireDevices.

pub async fn release_devices(&self, devices: &[&str]) -> Result<(), Error>

Release devices

Release all the devices whose ID is specified in devices.

Specifications

See also ReleaseDevices.

pub async fn receive_device_events( &self, ) -> Result<impl Stream<Item = UsbDeviceEvent>, Error>

Signal emitted on a device event

Will emit UsbDeviceEvent.

Specifications

See also DeviceEvents.